﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;

namespace TextAlignDemo
{
    public partial class Form1 : Form
    {
        private InMemoryFeatureLayer layer;
        private LayerOverlay staticOverlay;

        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            winformsMap1.MapUnit = GeographyUnit.DecimalDegree;
            winformsMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.FromArgb(255, 233, 232, 214));

            layer = new InMemoryFeatureLayer();
            layer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country2;
            layer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = new TextStyle("name", new GeoFont("Arial", 20), new GeoSolidBrush(GeoColor.SimpleColors.Black));
            layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            staticOverlay = new LayerOverlay();
            staticOverlay.Layers.Add(layer);
            winformsMap1.Overlays.Add(staticOverlay);

            layer.Open();
            layer.Columns.Add(new FeatureSourceColumn("name"));
            RectangleShape rectangleShape = new RectangleShape(-70, 40, 60, 10);
            Feature feature = new Feature(rectangleShape);
            feature.ColumnValues.Add("name", "");
            Feature centerPoint = new Feature(rectangleShape.GetCenterPoint());
            centerPoint.ColumnValues.Add("name", "Map Suite Desktop Edition");
            layer.InternalFeatures.Add(feature);
            layer.InternalFeatures.Add(centerPoint);

            winformsMap1.CurrentExtent = layer.GetBoundingBox();
            layer.Close();

            winformsMap1.Refresh();
        }

        private void cbxPointPlacement_SelectedIndexChanged(object sender, EventArgs e)
        {
            PointPlacement placement;
            switch (cbxPointPlacement.Text.Trim())
            {
                case "Center":
                    placement = PointPlacement.Center;
                    break;
                case "CenterLeft":
                    placement = PointPlacement.CenterLeft;
                    break;
                case "CenterRight":
                    placement = PointPlacement.CenterRight;
                    break;
                case "LowerCenter":
                    placement = PointPlacement.LowerCenter;
                    break;
                case "LowerLeft":
                    placement = PointPlacement.LowerLeft;
                    break;
                case "LowerRight":
                    placement = PointPlacement.LowerRight;
                    break;
                case "UpperCenter":
                    placement = PointPlacement.UpperCenter;
                    break;
                case "UpperLeft":
                    placement = PointPlacement.UpperLeft;
                    break;
                case "UpperRight":
                    placement = PointPlacement.UpperRight;
                    break;
                default:
                    placement = PointPlacement.CenterRight;
                    break;
            }

            layer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.PointPlacement = placement;

            winformsMap1.Refresh(staticOverlay);
        }
    }
}
